from wagtail.admin.edit_handlers import FieldPanel
from wagtail.admin.site_summary import SummaryItem
from wagtail.contrib.modeladmin.options import ModelAdmin, modeladmin_register
from wagtail.core import hooks
from wagtail_events.models import Event


class EventsSummaryItem(SummaryItem):
    order = 300
    template = 'wagtail_events/homepage/site_summary_events.html'

    def get_context(self):
        return {
            'total_events': Event.objects.count(),
        }


@hooks.register('construct_homepage_summary_items')
def add_homepage_summary_item(request, items):
    items.append(EventsSummaryItem(request))


class EventModelAdmin(ModelAdmin):

    model = Event

    menu_icon = 'date'  # change as required
    menu_order = 300  # will put in 3rd place (000 being 1st, 100 2nd)
    add_to_settings_menu = False  # or True to add your model to the Settings sub-menu
    exclude_from_explorer = False  # or True to exclude pages of this type from Wagtail's explorer view
    list_display = ('title', 'description',)
    list_filter = ('title', )
    search_fields = ('title', 'description',)

    # Editor panels configuration
    content_panels = [
        FieldPanel('title'),
    ]


modeladmin_register(EventModelAdmin)



from wagtail.core.models import PageManager


class DatedEventManager(PageManager):
    @staticmethod
    def _get_min_time(dt):
        """
        Makes clock to 00:00:00
        :param dt: datetime
        :return: datetime
        """
        return dt.replace(hour=0, minute=0, second=0)

    def in_date_range(self, start, end):
        """
        Get event dates that appear between the start and end dates
        :return: Filtered django model queryset
        """
        start = self._get_min_time(start)
        end = self._get_min_time(end)
        return self.filter(start_date__gte=start, start_date__lte=end)

    def live(self):
        """
        Get event dates associated with live event series
        :return: Filtered django model queryset
        """
        return self.filter(live=True)



import calendar
import datetime

from django.utils import timezone


_DATE_FORMAT_RE = r'^([0-9]){4}\.([0-9]){2}\.([0-9]){2}$'


def date_to_datetime(date, time_choice='min'):
    """
    Convert date to datetime.

    :param date: date to convert
    :param time_choice: max or min
    :return: datetime
    """
    choice = getattr(datetime.datetime, 'min' if time_choice == 'min' else 'max').time()
    return timezone.make_aware(
        datetime.datetime.combine(date, choice),
        timezone.get_current_timezone(),
    )


def add_months(date, months):
    """
    Add months to the date.

    :param date:
    :param months:
    :return:
    """
    month = date.month - 1 + months
    year = int(date.year + month / 12)
    month = month % 12 + 1
    day = min(date.day, calendar.monthrange(year, month)[1])
    return datetime.date(year, month, day)


def remove_months(date, months):
    """
    Add months to the date.

    :param date:
    :param months:
    :return:
    """
    month = date.month - 1 - months
    year = int(date.year + month / 12)
    month = month % 12 + 1
    day = min(date.day, calendar.monthrange(year, month)[1])
    return datetime.date(year, month, day)
